@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# $Id: problems.pl 1511 2007-01-21 19:09:00Z eugeniy $
+# $Id: problems.pl 680 2006-03-19 22:22:27Z src $
 
 # possible problems finder
 # (c)2004,2005 Stepan Roh (PUBLIC DOMAIN)
@@ -69,8 +69,6 @@ sub process_sfd_file($$) {
   my %all_glyphs = ();
   my $prev_enc = -1;
   my $in_spline_set = 0;
-  my $has_splines;
-  my $has_refs;
   open (SFD, $sfd_file) || die "Unable to open $sfd_file : $!\n";
   while (<SFD>) {
     if (/^StartChar:\s*(\S+)\s*$/) {
@@ -84,8 +82,6 @@ sub process_sfd_file($$) {
       @ligature_refs = ();
       $is_empty = 1;
       $in_spline_set = 0;
-      $has_splines = 0;
-      $has_refs = 0;
     } elsif (/^Colour:\s*(\S+)\s*/) {
       $colorized = $1;
     } elsif (/^Flags:\s*(\S+)\s*/) {
@@ -113,8 +109,6 @@ sub process_sfd_file($$) {
     } elsif (/^Fore\s*$/) {
       $is_empty = 0;
       $in_spline_set = 1;
-      problem (2, 'mixed content', $curchar, ' ', $dec_enc, ($hex_enc ? ' U+'.$hex_enc : '')) if ($has_refs);
-      $has_splines = 1;
     } elsif (/^EndSplineSet\s*$/) {
       $in_spline_set = 0;
     } elsif ($in_spline_set && !/.+,.+,.+$/) {
@@ -122,16 +116,8 @@ sub process_sfd_file($$) {
     } elsif (/^Ref:/) {
       $is_empty = 0;
       problem (0, 'not normalized: old-style "Ref"', $curchar, ' ', $dec_enc, ($hex_enc ? ' U+'.$hex_enc : ''));
-    } elsif (/^Refer:\s*\d+\s*\d+\s*\S\s*(-?\d+(?:\.\d*)?(?:e-?\d+)?)\s*(-?\d+(?:\.\d*)?(?:e-?\d+)?)\s*(-?\d+(?:\.\d*)?(?:e-?\d+)?)\s*(-?\d+(?:\.\d*)?(?:e-?\d+)?)\s*-?\d+(?:\.\d*)?(?:e-?\d+)?\s*-?\d+(?:\.\d*)?(?:e-?\d+)?\s*(\d+)/) {
+    } elsif (/^Refer:/) {
       $is_empty = 0;
-      if (($5 & 0x2) != 0x2) {
-        problem (0, 'reference is not rounded to grid', $curchar, ' ', $dec_enc, ($hex_enc ? ' U+'.$hex_enc : ''), ' flags=', $5);
-      }
-      if (!(($1 == 1) && ($2 == 0) && ($3 == 0) && ($4 == 1))) {
-        problem (0, 'transformed reference', $curchar, ' ', $dec_enc, ($hex_enc ? ' U+'.$hex_enc : ''));
-      }
-      problem (2, 'mixed content', $curchar, ' ', $dec_enc, ($hex_enc ? ' U+'.$hex_enc : '')) if ($has_splines);
-      $has_refs = 1;
     } elsif (/^DisplaySize:/) {
       problem (0, 'not normalized: DisplaySize');
     } elsif (/^WinInfo:/) {
