@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 
-# $Id: sfdnormalize.pl 1791 2007-05-15 19:25:40Z eugeniy $
+# $Id: sfdnormalize.pl 680 2006-03-19 22:22:27Z src $
 
 # SFD normalizer (discards GUI information from SFD files)
 # (c)2004,2005 Stepan Roh (PUBLIC DOMAIN)
@@ -21,9 +21,6 @@
 #   recalculate number of characters and positional encoding
 #   NameList
 #           - discarded (temporary)
-#   ModificationTime - discarded
-#   CreationTime - discarded
-#   VWidth - discarded (for now)
 # changes making it incompatible with FF older than (approx.) 20050728:
 #   Ref     - renamed to Refer
 #   KernsSLIF
@@ -48,8 +45,7 @@ sub process_sfd_file($) {
   my %pos_glyphs_map = ();
 
   while (<SFD>) {
-    next if (/^(WinInfo|DisplaySize|HStem|VStem|ModificationTime|CreationTime|VWidth):/);
-    s,^(NameList:).*$,$1 AGL without afii,;
+    next if (/^(WinInfo|DisplaySize|HStem|VStem|NameList):/);
     s,^Ref:,Refer:,;
     s,^KernsSLIF:,KernsSLIFO:,;
     s,^(Flags:.*?)O(.*)$,$1$2,;
@@ -64,15 +60,13 @@ sub process_sfd_file($) {
       $in_spline_set = 0;
     } elsif ($in_spline_set) {
       s/(\s+)(\S+?)(,\S+\s*)$/$1.($2 & ~4 & ~256).$3/e;
-      s/([\s^])-0(\s)/$1."0".$2/eg
     }
     if (/^BeginChars:/) {
       $in_chars = 1;
     } elsif (/^EndChars\s*$/) {
       $in_chars = 0;
       # adding of 1 to max_dec_enc is strange, but works
-      # second parameter is set to 0 to avoid merging conflicts (fontforge ignores anyway)
-      print OUT "BeginChars: ", $max_dec_enc + 1, " 0\n";
+      print OUT "BeginChars: ", $max_dec_enc + 1, " ", scalar (keys %glyphs), "\n";
       foreach $glyph (sort { $glyphs{$a}{'dec_enc'} <=> $glyphs{$b}{'dec_enc'} } keys %glyphs) {
         print OUT "StartChar: ", $glyphs{$glyph}{'name'}, "\n";
         my $dec_enc = $glyphs{$glyph}{'dec_enc'};
